@@ -215,6 +215,7 @@ view_tmap <- function(gp, shps=NULL, leaflet_id=1, showWarns=TRUE) {
 			
 			fixed <- ifelse(gpl$symbol.misc$symbol.are.dots, gt$dot.size.fixed, gt$symbol.size.fixed)
 			are.icons <- gpl$symbol.misc$symbol.are.icons
+			clustering <- gpl$symbol.misc$clustering
 			
 			if (are.icons) {
 				#symbol.size2 <- symbol.size2 / 3 # Correct for the fact that markers are larger than circle markers. This is good, but for static plots the icon size was already increased by icon.size=3, so this is to revert it for view mode
@@ -231,7 +232,7 @@ view_tmap <- function(gp, shps=NULL, leaflet_id=1, showWarns=TRUE) {
 						icons$iconAnchorY <- icons$iconAnchorY * symbol.size2
 					}
 				}
-				lf <- lf %>% addMarkers(lng = co2[,1], lat=co2[,2], popup=popups2, group=shp_name, icon=icons, layerId = id)
+				lf <- lf %>% addMarkers(lng = co2[,1], lat=co2[,2], popup=popups2, group=shp_name, icon=icons, layerId = id, clusterOptions=clustering)
 			} else {
 				if (!all(symbol.shape2 %in% c(1, 16, 19, 20, 21))) {
 					warns["symbol"] <- TRUE
@@ -239,7 +240,7 @@ view_tmap <- function(gp, shps=NULL, leaflet_id=1, showWarns=TRUE) {
 				}
 
 				if (fixed) {
-					lf <- lf %>% addCircleMarkers(lng=co2[,1], lat=co2[,2], fill = any(!is.na(fcol2)), fillColor = fcol2, fillOpacity=fopacity, color = bcol, stroke = !is.na(bcol) && bopacity!=0, radius = 20*symbol.size2, weight = 1, popup=popups2, group=shp_name, layerId = id, popupOptions = pOptions)
+					lf <- lf %>% addCircleMarkers(lng=co2[,1], lat=co2[,2], fill = any(!is.na(fcol2)), fillColor = fcol2, fillOpacity=fopacity, color = bcol, stroke = !is.na(bcol) && bopacity!=0, radius = 20*symbol.size2, weight = 1, popup=popups2, group=shp_name, layerId = id, popupOptions = pOptions, clusterOptions=clustering)
 				} else {
 					lf <- lf %>% addCircles(lng=co2[,1], lat=co2[,2], fill = any(!is.na(fcol2)), fillColor = fcol2, fillOpacity=fopacity, color = bcol, stroke = !is.na(bcol) && bopacity!=0, radius=rad, weight =1, popup=popups2, group=shp_name, layerId = id, popupOptions = pOptions)
 				}
@@ -574,9 +575,16 @@ add_legend <- function(map, gpl, gt, aes, alpha, list.only=FALSE) {
 		}
 	}
 
-	RGBA <- col2rgb(pal, alpha = TRUE)
-	col <- rgb(RGBA[1,], RGBA[2,], RGBA[3,], maxColorValue = 255)
-	opacity <- unname(RGBA[4,1]/255) * alpha
+	allNAs <- (length(pal) == 0)
+	
+	if (allNAs) {
+		col <- character()
+		opacity <- alpha
+	} else {
+		RGBA <- col2rgb(pal, alpha = TRUE)
+		col <- rgb(RGBA[1,], RGBA[2,], RGBA[3,], maxColorValue = 255)
+		opacity <- unname(RGBA[4,1]/255) * alpha
+	}
 	
 	if (!is.na(colNA)) {
 		RGBA_NA <- col2rgb(colNA, alpha = TRUE)
@@ -605,10 +613,14 @@ add_legend <- function(map, gpl, gt, aes, alpha, list.only=FALSE) {
 					  pal=colorNumeric(col, val, na.color=colNA, alpha = FALSE), values=legvals, na.label = textNA, title=title, opacity=opacity)
 		}
 	} else {
-		legvals <- if (!is.na(colNA)) factor(c(lab, NA), levels=lab) else factor(lab, levels=lab)
-		lab <- factor(lab, levels=lab)
-		addLegend(map, position=legend.position, 
-				  pal=colorFactor(col, domain=lab, na.color = colNA, ordered = TRUE, alpha = FALSE), values = legvals, na.label=textNA, title=title, opacity=opacity)
+		if (allNAs) {
+			addLegend(map, position=legend.position, colors=colNA, labels=textNA, title=title, opacity=opacity)
+		} else {
+			legvals <- if (!is.na(colNA)) factor(c(lab, NA), levels=lab) else factor(lab, levels=lab)
+			lab <- factor(lab, levels=lab)
+			addLegend(map, position=legend.position, 
+					  pal=colorFactor(col, domain=lab, na.color = colNA, ordered = TRUE, alpha = FALSE), values = legvals, na.label=textNA, title=title, opacity=opacity)
+		}
 	}
 }
 
